@@ -28,6 +28,9 @@
 # files in the program, then also delete it here.
 """Qt implementation of the UI."""
 
+import platform
+import urllib
+
 from functools import wraps
 
 # pylint: disable=F0401,E0611
@@ -44,7 +47,7 @@ from PyQt4.QtGui import (
 )
 from twisted.internet import defer
 
-from ubuntu_sso import main
+from ubuntu_sso import constants, main
 from ubuntu_sso.logger import setup_gui_logging, log_call
 from ubuntu_sso.qt import (
     ERROR_STYLE,
@@ -58,6 +61,25 @@ from ubuntu_sso.utils.ui import GENERIC_BACKEND_ERROR
 logger = setup_gui_logging('ubuntu_sso.sso_wizard_page')
 
 
+def platform_data():
+    result = {'platform': platform.system(),
+              'platform_version': platform.release(),
+              'platform_arch': platform.machine(),
+              'client_version': constants.VERSION}
+    # urlencode will not encode unicode, only bytes
+    result = urllib.urlencode(result)
+    return result
+
+
+APP_NAME = u"Ubuntu One"
+TC_URL = u"https://one.ubuntu.com/terms/"
+POLICY_URL = u"https://one.ubuntu.com/privacy/"
+BASE_PING_URL = \
+    u"https://one.ubuntu.com/oauth/sso-finished-so-get-tokens/{email}"
+# the result of platform_data is given by urlencode, encoded with ascii
+PING_URL = BASE_PING_URL + u"?" + platform_data().decode('ascii')
+
+
 class WizardHeader(QFrame):
     """WizardHeader Class for Title and Subtitle in all wizard pages."""
 
@@ -201,10 +223,10 @@ class SSOWizardPage(BaseWizardPage):
         super(SSOWizardPage, self).__init__(parent=parent)
 
         # store common useful data provided by the app
-        self.app_name = app_name
-        self.ping_url = kwargs.get('ping_url', '')
-        self.tc_url = kwargs.get('tc_url', '')
-        self.policy_url = kwargs.get('policy_url', '')
+        self.app_name = APP_NAME
+        self.ping_url = PING_URL
+        self.tc_url = TC_URL
+        self.policy_url = POLICY_URL
         self.help_text = kwargs.get('help_text', '')
 
         self._signals_receivers = {}
