@@ -61,22 +61,6 @@ class FakeWebclient(object):
         """Shutdown this fake webclient."""
 
 
-class FakedOAuthRequest(object):
-    """Replace the OAuthRequest class."""
-
-    params = {}
-
-    def __init__(self):
-        self.sign_request = lambda *args, **kwargs: None
-        self.to_header = lambda *args, **kwargs: {}
-
-    def from_consumer_and_token(oauth_consumer, **kwargs):
-        """Fake the method storing the params for check."""
-        FakedOAuthRequest.params.update(kwargs)
-        return FakedOAuthRequest()
-    from_consumer_and_token = staticmethod(from_consumer_and_token)
-
-
 class FakedConstantsModule(object):
     """Fake the 'ubuntuone.controlpanel.constants' module."""
 
