@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2011-2012 Canonical Ltd.
+# Copyright 2011-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -43,13 +43,12 @@ except ImportError:
     from urlparse import urlparse, urljoin, parse_qsl
 
 from OpenSSL import crypto
-from oauth import oauth
 from socket import gethostname
 from twisted.cred import checkers, portal
 from twisted.internet import defer
 from twisted.web import guard, http, resource
 from ubuntuone.devtools.handlers import MementoHandler
-from ubuntuone.devtools.testcases import TestCase
+from ubuntuone.devtools.testcases import TestCase, skipIfOS
 from ubuntuone.devtools.testcases.squid import SquidTestCase
 from ubuntuone.devtools.testing.txwebserver import (
     HTTPWebServer,
@@ -69,7 +68,6 @@ from ubuntu_sso.utils.webclient import gsettings, txweb
 from ubuntu_sso.utils.webclient.common import (
     BaseWebClient,
     HeaderDict,
-
     UnauthorizedError,
     WebClientError,
 )
@@ -378,7 +376,7 @@ class WebClientTestCase(TestCase):
     def test_request_is_oauth_signed(self):
         """The request is oauth signed."""
         tsc = self.wc.get_timestamp_checker()
-        self.patch(tsc, "get_faithful_time", lambda: defer.succeed(1))
+        self.patch(tsc, "get_faithful_time", lambda: defer.succeed('1'))
         result = yield self.wc.request(self.base_iri + OAUTHRESOURCE,
                                        oauth_credentials=SAMPLE_CREDENTIALS)
         self.assertEqual(SAMPLE_RESOURCE, result.content)
@@ -391,7 +389,7 @@ class WebClientTestCase(TestCase):
         def fake_get_faithful_time():
             """A fake get_timestamp"""
             called.append(True)
-            return defer.succeed(1)
+            return defer.succeed('1')
 
         tsc = self.wc.get_timestamp_checker()
         self.patch(tsc, "get_faithful_time", fake_get_faithful_time)
@@ -403,7 +401,7 @@ class WebClientTestCase(TestCase):
     def test_returned_content_are_bytes(self):
         """The returned content are bytes."""
         tsc = self.wc.get_timestamp_checker()
-        self.patch(tsc, "get_faithful_time", lambda: defer.succeed(1))
+        self.patch(tsc, "get_faithful_time", lambda: defer.succeed('1'))
         result = yield self.wc.request(self.base_iri + OAUTHRESOURCE,
                                        oauth_credentials=SAMPLE_CREDENTIALS)
         self.assertTrue(isinstance(result.content, bytes),
@@ -567,6 +565,8 @@ class BasicProxyTestCase(SquidTestCase):
         result = yield self.wc.request(self.base_iri + SIMPLERESOURCE)
         self.assert_header_contains(result.headers["Via"], "squid")
 
+    @skipIfOS('linux2',
+              'LP: #1111880 - ncsa_auth crashing for auth proxy tests.')
     @defer.inlineCallbacks
     def test_authenticated_proxy_is_used(self):
         """The authenticated proxy is used by the webclient."""
@@ -575,6 +575,8 @@ class BasicProxyTestCase(SquidTestCase):
         result = yield self.wc.request(self.base_iri + SIMPLERESOURCE)
         self.assert_header_contains(result.headers["Via"], "squid")
 
+    @skipIfOS('linux2',
+              'LP: #1111880 - ncsa_auth crashing for auth proxy tests.')
     @defer.inlineCallbacks
     def test_auth_proxy_is_used_creds_requested(self):
         """The authenticated proxy is used by the webclient."""
@@ -594,6 +596,8 @@ class BasicProxyTestCase(SquidTestCase):
         result = yield self.wc.request(self.base_iri + SIMPLERESOURCE)
         self.assert_header_contains(result.headers["Via"], "squid")
 
+    @skipIfOS('linux2',
+              'LP: #1111880 - ncsa_auth crashing for auth proxy tests.')
     @defer.inlineCallbacks
     def test_auth_proxy_is_requested_creds_bad_details(self):
         """Test using wrong credentials with the proxy."""
@@ -615,6 +619,8 @@ class BasicProxyTestCase(SquidTestCase):
         result = yield self.wc.request(self.base_iri + SIMPLERESOURCE)
         self.assert_header_contains(result.headers["Via"], "squid")
 
+    @skipIfOS('linux2',
+              'LP: #1111880 - ncsa_auth crashing for auth proxy tests.')
     @defer.inlineCallbacks
     def test_auth_proxy_is_requested_creds_bad_details_user(self):
         """Test using no creds and user providing the wrong ones."""
@@ -638,6 +644,8 @@ class BasicProxyTestCase(SquidTestCase):
         result = yield self.wc.request(self.base_iri + SIMPLERESOURCE)
         self.assert_header_contains(result.headers["Via"], "squid")
 
+    @skipIfOS('linux2',
+              'LP: #1111880 - ncsa_auth crashing for auth proxy tests.')
     @defer.inlineCallbacks
     def test_auth_proxy_is_requested_creds_bad_details_everywhere(self):
         """Test when we pass the wrong settings and get the wrong settings."""
@@ -663,6 +671,8 @@ class BasicProxyTestCase(SquidTestCase):
         result = yield self.wc.request(self.base_iri + SIMPLERESOURCE)
         self.assert_header_contains(result.headers["Via"], "squid")
 
+    @skipIfOS('linux2',
+              'LP: #1111880 - ncsa_auth crashing for auth proxy tests.')
     def test_auth_proxy_is_requested_user_cancels(self):
         """Test when the user cancels the creds dialog."""
         settings = self.get_auth_proxy_settings()
@@ -722,7 +732,7 @@ class OAuthPlainTextTestCase(TestCase):
     sample_method = "GET"
     sample_url = "http://one.ubuntu.com/"
     sample_params = {'next': 'yadda-yadda-yo', 'foo': 'naranja fanta'}
-    timestamp = 1
+    timestamp = '1'
     expected_params = {
         "oauth_timestamp": str(timestamp),
         "oauth_consumer_key": SAMPLE_CREDENTIALS["consumer_key"],
@@ -777,16 +787,17 @@ class OAuthPlainTextTestCase(TestCase):
 
     def test_build_oauth_request(self, params=None):
         """Check that the oauth request are properly built."""
-        request = self.wc.build_oauth_request(self.sample_method,
-                           self.sample_url, SAMPLE_CREDENTIALS, self.timestamp,
-                           parameters=params)
+        url, signed_headers, body = self.wc.build_oauth_request(
+            self.sample_method,
+            self.sample_url, SAMPLE_CREDENTIALS, self.timestamp,
+            parameters=params, as_query=False)
 
-        self.assert_headers_correct(request.to_header())
-        self.assertEqual(request.http_url, self.sample_url)
+        self.assert_headers_correct(signed_headers)
+        self.assertEqual(url, self.sample_url)
         if params is not None:
             for param, value in params.items():
-                self.assertIn(param, request.parameters)
-                actual = request.parameters[param]
+                self.assertIn(param, body)
+                actual = body[param]
                 self.assertEqual(value, actual)
 
     def test_build_oauth_request_with_params(self):
@@ -799,23 +810,23 @@ class OAuthPlainTextTestCase(TestCase):
         self.patch(self.wc, 'get_timestamp', lambda: self.timestamp)
         iri = u'http://foo.bar.baz/ñandú'
         uri = self.wc.iri_to_uri(iri)
-        request = self.wc.build_oauth_request(self.sample_method,
-                           uri, SAMPLE_CREDENTIALS,
-                           self.timestamp, parameters=params)
-
-        result = yield self.wc.build_signed_iri(iri, SAMPLE_CREDENTIALS,
-                                          parameters=params)
+        # request will be a 3-tuple of the url, signed headers, and body.
+        url, signed_headers, body = self.wc.build_oauth_request(
+            self.sample_method,
+            uri, SAMPLE_CREDENTIALS,
+            self.timestamp, parameters=params)
+        scheme, netloc, path, params, query, _ = urlparse(url)
+        expected = dict(parse_qsl(query))
 
+        result = yield self.wc.build_signed_iri(
+            iri, SAMPLE_CREDENTIALS, parameters=params)
         scheme, netloc, path, params, query, _ = urlparse(result)
-
         self.assertEqual(urljoin(scheme + '://' + netloc, path), uri)
-
-        expected = request.parameters
         actual = dict(parse_qsl(query))
+
         for i in ('oauth_nonce', 'oauth_signature'):
             expected.pop(i)
             actual.pop(i)
-        actual['oauth_timestamp'] = int(actual['oauth_timestamp'])
         self.assertEqual(expected, actual)
 
     def test_build_signed_iri_with_params(self, params=None):
@@ -828,24 +839,6 @@ class OAuthPlainTextTestCase(TestCase):
         setattr(src, attr_name, staticmethod(replacement))
         self.addCleanup(setattr, src, attr_name, staticmethod(original))
 
-    def test_iri_parameters_used_in_oauth_signature(self):
-        """The iri parameters are used in the oauth signature."""
-        from_consumer_and_token = oauth.OAuthRequest.from_consumer_and_token
-
-        def fake_from_consumer_and_token(parameters=None, **kwargs):
-            """Verify the parameters passed."""
-            self.assertIn("fake_param", parameters)
-            return from_consumer_and_token(
-                                        parameters=parameters, **kwargs)
-
-        self.patch_staticmethod(oauth.OAuthRequest, "from_consumer_and_token",
-                                fake_from_consumer_and_token)
-
-        self.sample_url += "?fake_param=fake_value"
-        self.wc.build_oauth_request(self.sample_method, self.sample_url,
-                                    SAMPLE_CREDENTIALS, self.timestamp,
-                                    parameters={})
-
 
 class OAuthHmacSha1TestCase(OAuthPlainTextTestCase):
     """Test for the oauth signing code using HMAC-SHA1."""
